<?php
/**
 * Theme functions and definitions
 *
 * @package Sublime_Blog
 */

/**
 * After setup theme hook
 */
function sublime_journal_theme_setup(){
    /*
     * Make child theme available for translation.
     * Translations can be filed in the /languages/ directory.
     */
    load_child_theme_textdomain( 'sublime-journal', get_stylesheet_directory() . '/languages' );

    add_image_size( 'sublime-journal-slider', 1170, 600, true );
    add_image_size( 'sublime-journal-featured', 540, 768, true );
    
}
add_action( 'after_setup_theme', 'sublime_journal_theme_setup' );

function sublime_blog_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    /*
    * translators: If there are characters in your language that are not supported
    * by Poppins, translate this to 'off'. Do not translate into your own language.
    */
    if ( 'off' !== _x( 'on', 'Nunito Sans font: on or off', 'sublime-journal' ) ) {
        $fonts[] = 'Nunito Sans:300,300i,400,400i,600,600i,700,700i';
    }

    if ( $fonts ) {
        $fonts_url = add_query_arg(
            array(
                'family'  => urlencode( implode( '|', $fonts ) ),
                'display' => urlencode( 'swap' ),
            ),
            'https://fonts.googleapis.com/css'
        );
    }

    return esc_url( $fonts_url );
}

/**
 * Load assets.
 */
function sublime_journal_enqueue_styles() {
    $my_theme = wp_get_theme();
    $version = $my_theme['Version'];
    wp_enqueue_style( 'sublime-journal-style', get_stylesheet_directory_uri() . '/style.css', array( 'sublime-blog-style' ), $version );    
    wp_enqueue_script( 'sublime-journal-custom', get_stylesheet_directory_uri() . '/js/custom.js', array(), $version, true );
}
add_action( 'wp_enqueue_scripts', 'sublime_journal_enqueue_styles', 11 );

function sublime_blog_body_classes( $classes ) {
    global $post;
    // Adds a class of hfeed to non-singular pages.
    if ( ! is_singular() ) {
        $classes[] = 'hfeed';
    }
    if( is_active_sidebar( 'sidebar' ) ){

        if( is_home() || is_archive() || is_search() ){
            $classes[] = 'list-layout rightsidebar';
        }
    
        if( is_singular() ){
            $sidebar_layout = get_post_meta( $post->ID, '_sublime_blog_sidebar_layout', true );
            if( $sidebar_layout == 'no-sidebar' ){
                $classes[] = 'fullwidth';
            }else{
                $classes[] = 'rightsidebar';
            }
        }
    }else{
        $classes[] = 'fullwidth';
    }

    if( is_404() ){
        $classes[] = 'fullwidth';
    }

    return $classes;
}

/*
 *Overriding the Parent header
*/
function sublime_blog_header(){ ?>
    <header id="masthead" class="site-header layout-three" itemscope itemtype="http://schema.org/WPHeader">
        <div class="top-header">
            <div class="container">
                <div class="site-branding" itemscope itemtype="http://schema.org/Organization">
                    <?php the_custom_logo(); ?>

                    <div class="site-title-wrap">
                        <?php
                        if ( is_front_page() && is_home() ) : ?>
                            <h1 class="site-title" itemprop="name"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" itemprop="url"><?php bloginfo( 'name' ); ?></a></h1>
                        <?php
                        else : ?>
                            <p class="site-title" itemprop="name"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" itemprop="url"><?php bloginfo( 'name' ); ?></a></p>
                            <?php
                        endif;
                        $sublime_blog_description = get_bloginfo( 'description', 'display' );
                        if ( $sublime_blog_description || is_customize_preview() ) : ?>
                            <p class="site-description" itemprop="description"><?php echo $sublime_blog_description; /* WPCS: xss ok. */ ?></p>
                        <?php endif; ?>
                    </div>
                </div><!-- .site-branding -->
            </div>
        </div><!-- .top-header -->
        <div class="nav-wrap">
            <div class="container">
                <nav id="site-navigation" class="main-navigation" itemscope itemtype="http://schema.org/SiteNavigationElement">
                    <button class="toggle-button" aria-controls="primary-menu" data-toggle-target=".main-menu-modal" data-toggle-body-class="showing-main-menu-modal" aria-expanded="false" data-set-focus=".close-main-nav-toggle">
						<span class="toggle-bar"></span>
						<span class="toggle-bar"></span>
						<span class="toggle-bar"></span>
					</button><!-- .toggle-button -->
                    <div class="primary-menu-list main-menu-modal cover-modal" data-modal-target-string=".main-menu-modal">
                        <button class="close close-main-nav-toggle" data-toggle-target=".main-menu-modal" data-toggle-body-class="showing-main-menu-modal" aria-expanded="false" data-set-focus=".main-menu-modal">
                            <span class="toggle-bar"></span>
                        </button>
                        <div class="mobile-menu" aria-label="<?php esc_attr_e( 'Mobile', 'sublime-journal' ); ?>">
                            <?php
                            wp_nav_menu( array(
                                'theme_location' => 'primary',
                                'menu_id'        => 'primary-menu',
                                'menu_class'     => 'menu main-menu-modal',
                            ) );
                            ?>
                        </div>
                    </div>
                </nav><!-- #site-navigation -->
                <?php if( get_theme_mod( 'ed_header_search',true ) ) : ?>               
                    <div class="header-right">
                        <div class="header-search">
                            <button class="search-toggle" data-toggle-target=".search-modal" data-toggle-body-class="showing-search-modal" data-set-focus=".search-modal .search-field" aria-expanded="false">
                                <i class="fas fa-search"></i>
                            </button>
                            <div class="header-search-wrap search-modal cover-modal" data-modal-target-string=".search-modal">
                                <div class="header-search-inner-wrap">
                                    <?php get_search_form(); ?>
                                    <button class="close" data-toggle-target=".search-modal" data-toggle-body-class="showing-search-modal" data-set-focus=".search-modal .search-field" aria-expanded="false"></button>
                                </div>
                            </div><!-- .header-search-wrap -->
                        </div><!-- .header-search -->
                    </div><!-- .header-left -->
                <?php endif; ?>
            </div>
        </div>
    </header><!-- #masthead -->
    <?php 
}

function sublime_blog_slider(){
    if( is_front_page() ){
        $ed_slider      = get_theme_mod( 'ed_slider_section', false );
        $slider_type    = get_theme_mod( 'slider_type', 'latest_posts' );
        $slider_cat     = get_theme_mod( 'slider_cat' );
        $posts_per_page = get_theme_mod( 'no_of_slides', 3 );
        if( $ed_slider ){
            $slider_arg = array(
                'post_type'           => 'post',
                'post_status'         => 'publish',            
                'ignore_sticky_posts' => true
            );

            if( $slider_type === 'cat' && $slider_cat ){
                $slider_arg['cat']            = $slider_cat; 
                $slider_arg['posts_per_page'] = -1;  
            }else{
                $slider_arg['posts_per_page'] = $posts_per_page;
            }

            $slider_qry = new WP_Query( $slider_arg );
            
            if( $slider_qry->have_posts() ){
                echo '<div class="site-banner layout-four"><div class="banner-items-sj owl-carousel">';
                while( $slider_qry->have_posts() ){
                    $slider_qry->the_post();
                    if( has_post_thumbnail() ){ ?>
                        <div class="banner-item">
                            <?php the_post_thumbnail( 'sublime-journal-slider', array( 'itemprop' => 'image' ) ); ?>
                            <div class="item-content">
                                <div class="item-content-inner">
                                    <?php 
                                        /* translators: used between list items, there is a space after the comma */
                                        $categories_list = get_the_category_list( esc_html__( ', ', 'sublime-journal' ) );
                                        if( $categories_list ) printf( '<span class="category" itemprop="about">%1$s</span>', $categories_list ); // WPCS: XSS OK.
                                        the_title( '<h2 class="item-title"><a href="' . esc_url( get_permalink() ) . '">', '</a></h2>' );
                                    ?>
                                </div>
                            </div>
                        </div><!-- .banner-item -->
                        <?php
                    }
                }
                echo '</div><!-- .banner-items --></div><!-- .site-banner -->';
                wp_reset_postdata();
            } 
        }
    } 
}

function sublime_blog_post_thumbnail() {
    global $post;
    if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
        return;
    }
    $sidebar_layout = get_post_meta( $post->ID, '_sublime_blog_sidebar_layout', true );
    if( is_active_sidebar( 'sidebar' ) && $sidebar_layout == 'right-sidebar' ){
        $image_size = 'sublime-blog-featured';
    }else{
        $image_size = 'sublime-blog-slider';
    }

    if ( is_singular() ) : ?>

        <figure class="post-thumbnail">
            <?php the_post_thumbnail( $image_size, array( 'itemprop' => 'image' ) ); ?>
        </figure><!-- .post-thumbnail -->

    <?php else : ?>

    <a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true">
        <?php
            the_post_thumbnail( 'sublime-journal-featured', 
                array(
                    'alt' => the_title_attribute( array(
                        'echo' => false,
                    ) ),
                    'itemprop' => 'image'
                ) 
            );
        ?>
    </a>

    <?php
    endif; // End is_singular().
}

function sublime_blog_footer_copyright(){
    $copyright = get_theme_mod( 'copyright' );
    echo '<span class="copyright">';
    if( $copyright ){
        echo wp_kses_post( $copyright );
    } 
    echo '</span>';
    /* translators: 1: Theme name, 2: Theme author. */
    printf( esc_html__( 'Theme: %1$s by %2$s.', 'sublime-journal' ), 'Sublime Journal', '<a href="'.esc_url( 'https://sublimetheme.com/' ).'" rel="nofollow" target="_blank" >SublimeTheme</a>' );
}

function sublime_blog_customize_register_info( $wp_customize ) {

    $wp_customize->add_section( 'theme_info' , array(
        'title'       => __( 'Information Links', 'sublime-journal' ),
        'priority'    => 6,
        'capability' => 'edit_theme_options'
        )
    );

    $wp_customize->add_setting('theme_info_theme',array(
        'default'           => '',
        'sanitize_callback' => 'wp_kses_post',
        )
    );
    
    $theme_info = '';
    $theme_info .= '<span class="sticky_info_row"><span class="emoji dashicons emoji dashicons-visibility"></span><a href="' . esc_url( 'https://sublimetheme.com/theme/sublime-journal/' ) . '"  target="_blank">' . __( 'View demo', 'sublime-journal' ) . '</a></span><br />';
    $theme_info .= '<span class="sticky_info_row"><span class="emoji dashicons emoji dashicons-text-page"></span><a href="' . esc_url( 'https://sublimetheme.com/docs/sublime-journal/' ) . '" target="_blank">' . __( 'View documentation', 'sublime-journal' ) . '</a></span><br />';
    $theme_info .= '<span class="sticky_info_row"><span class="emoji dashicons emoji dashicons-info"></span><a href="' . esc_url( 'https://sublimetheme.com/theme/sublime-journal/' ) . '" target="_blank">' . __( 'Theme info', 'sublime-journal' ) . '</a></span><br />';
    $theme_info .= '<span class="sticky_info_row"><span class="emoji dashicons emoji dashicons-tickets"></span><a href="' . esc_url( 'https://sublimetheme.com/support/' ) . '" target="_blank">' . __( 'Support ticket', 'sublime-journal' ) . '</a></span><br />';
    $theme_info .= '<span class="sticky_info_row"><span class="emoji dashicons emoji dashicons-star-filled"></span><a href="' . esc_url( 'https://wordpress.org/support/theme/sublime-journal/reviews/#new-post' ) . '" target="_blank">' . __( 'Rate this theme', 'sublime-journal' ) . '</a></span><br />';

    $wp_customize->add_control( 
        new Sublime_Blog_Theme_Info( $wp_customize ,'theme_info_theme',array(
        'label'       => __( 'Information Links', 'sublime-journal' ),
        'section'     => 'theme_info',
        'description' => $theme_info
        )
    ));

    $wp_customize->add_setting('theme_info_more_theme',array(
        'default' => '',
        'sanitize_callback' => 'wp_kses_post',
    ));
}